﻿using System;
using System.Windows;
using System.Windows.Threading;
using SpreadsheetOwnerErrorSampleV3.Core.Bootstrapper;

namespace SpreadsheetOwnerErrorSampleV3
{
	/// <summary>
	/// Interaction logic for App.xaml
	/// </summary>
	public partial class App : Application
	{
		public App()
		{
			DispatcherUnhandledException += OnDispatcherUnhandledException;
			AppDomain.CurrentDomain.UnhandledException += OnUnhandledException;
		}

		private void OnUnhandledException(object sender, UnhandledExceptionEventArgs args)
		{
			ErrorHandler.OnError(/*sLog,*/ args.ExceptionObject as Exception, "Unhandled Exception occurred!");
		}

		private static void OnDispatcherUnhandledException(object sender, DispatcherUnhandledExceptionEventArgs args)
		{
			args.Handled = true;
			ErrorHandler.OnError(/*sLog,*/ args.Exception, "Fatal Exception occurred!");
		}

		/// <inheritdoc />
		protected override void OnStartup(StartupEventArgs e)
		{
			try
			{

				base.OnStartup(e);

				// Configure Bootstrapper
				var bootstrapper = new AppBootstrapper();
				bootstrapper.Run();

				base.OnStartup(e);
			}
			catch (Exception ex)
			{
				try
				{
					ErrorHandler.OnError(ex, "App bootstrapper", "Failed to load App.xaml");
				}
				finally
				{
					Current.Shutdown();
				}
			}
		}
	}
}
